@@ -4,5 +4,6 @@ Module for stacking datasets along the time dimension in a single file.
 """
 from __future__ import absolute_import
 from .stacker import main
+from .fixer import fixer as fixer_main
 
-__all__ = ['main']
+__all__ = ['main', 'fixer_main']
